@@ -1,5 +1,5 @@
 /* ************************************************************************* *
-   xfsm - (C) Copyright 1993 Robert Gasch (rgasch@nl.oracle.com)
+   xfsm - (C) Copyright 1993-1996 Robert Gasch (Robert_Gasch@peoplesoft.com)
 
    Permission to use, copy, modify and distribute this software for any 
    purpose and without fee is hereby granted, provided that this copyright
@@ -11,7 +11,7 @@
    any purpose. This software is provided "as is" without express or implied 
    warranty.
 
-   All commercial uses of xfsm must be done by agreement with the autor.
+   See the GNU General Public Licence for more information.
  * ************************************************************************* */
 
 
@@ -48,9 +48,11 @@ extern int 			show_use,
 				detail_share_color,
 				minimize,
 				menu_border,
+				show_biggest,
 				fs_border,
 				percent,
 				absolute,
+				available,
 				bell,
 				verbose,
 				gray,
@@ -236,11 +238,24 @@ void toggle_mode ()
 /* *********************************************************************** */
 void redraw_main_win ()
 {
-	int 		i, should_bell = FALSE;
+	int 		i, should_bell = FALSE, posx, posy;
 	int 		text_width = main_win.width-(OFF_X+OFF_X+
-				percent_width*percent);
+				percent_width*(percent|available));
+	char		s[10];
 	unsigned long	color;
 
+	if (show_biggest)
+		{
+		if (b_disk > GB)
+			sprintf (s, "%.1fGB ", b_disk/GB);
+		else
+			sprintf (s, "%.1fMB ", b_disk/MB);
+		posx = main_win.width-XTextWidth(main_win.font_info, 
+			s, strlen (s));
+		posy = main_win.height-MENU_HEIGHT(menu[0]);
+		XDrawImageString (mydisplay, main_win.win, main_win.gc,
+			posx, posy, s, strlen (s));
+		}
 	for (i = 0; i < NFS; i++) 
 		{
 		if (minimize == MNL)
@@ -290,6 +305,8 @@ void redraw_main_win ()
 
 		if (percent)
 			write_percent (i);
+		if (available)
+			write_available (i);
 		}
 
 	if (should_bell)
@@ -314,6 +331,29 @@ int i;
 
 
 
+/* *********************************************************************** */
+/* ************************* write available space *********************** */
+/* *********************************************************************** */
+void write_available(i)
+int i;
+{
+	char	s[30];
+	long	bsize=stats[i].f_bsize;
+
+	sprintf (s, "%5.2f", 
+#ifdef SCO
+		((double)(bsize)/(float)(MB))*(double)(stats[i].f_bfree));
+#else
+		((double)(bsize)/(float)(MB))*(double)(stats[i].f_bavail));
+#endif /* SCO */
+	XDrawImageString (mydisplay, main_win.win, main_win.gc, 
+		(main_win.width - OFF_Y -
+		XTextWidth(main_win.font_info, s, strlen(s))),
+ 		fs_win[i].y - 2, s, strlen (s));
+}
+
+
+
 /* *********************************************************************** */
 /* ************************* write the percentage ************************ */
 /* *********************************************************************** */
