@@ -1,5 +1,5 @@
 /* ************************************************************************* *
-   xfsm - (C) Copyright 1993 Robert Gasch (rgasch@nl.oracle.com)
+   xfsm - (C) Copyright 1993-1996 Robert Gasch (Robert_Gasch@peoplesoft.com)
 
    Permission to use, copy, modify and distribute this software for any 
    purpose and without fee is hereby granted, provided that this copyright
@@ -11,7 +11,7 @@
    any purpose. This software is provided "as is" without express or implied 
    warranty.
 
-   All commercial uses of xfsm must be done by agreement with the autor.
+   See the GNU General Public Licence for more information.
  * ************************************************************************* */
 
 
@@ -23,6 +23,7 @@
 	+rv			reverse video (use to override xrdb entry) 
 	+synchronous		syncronous mode (use to override xrdb entry)
 	-?			help
+	-A			show available space in MB
 	-a			absolute display mode
 	-background <arg>	backgound color 
 	-b			black bars (disable gray fill)
@@ -55,6 +56,9 @@
 	-r			display space with respect to root
 	-rs <arg>		specify the amount of space reserved for root
 	-rv 			reverse video
+	-s <arg1 ... argn>	show only these file systems
+	-S <arg1 ... argn>	select only file systems matching these patterns
+	-sb			show biggest file system size in lower right 
 	-sort			sort file systems according to name 
 	-synchronous		synchronous mode
 	-v			verbose
@@ -225,6 +229,32 @@
 			changed Imakefile, APP_DEFAULTS_DIR handling and 
 			the format of the call the DefaultDepth which 
 			broke some preprocessors.
+	09-09-94: 1.83
+			added check for resrouce file. Xfsm will now look 
+			first in XAPPLRESDIR. If that turns up empty, we
+			look in  APP_DEFAULTS_DIR (which is the global 
+			preferences stuff). Also fixed the problem with 
+			system which don't allow the stat() shortcut where 
+			file systems of size 0 are reported on each update 
+			in verbose mode.
+	21-10-94: 1.84
+			fixed -fb flag message 
+	11-11-94: 1.85
+			added SGI ifdefs
+	31-03-95: 1.86
+			Fixed handling of any file system type containing the 
+                        string "msdos": no reserved space is assumed now,
+			fixed potential core dump when checking non-existant
+                        XAPPLRESDIR, reduced SCO detail window size, added 
+			-sb flag, fixed unitialized msg in process_databases().
+
+	04-05-95: 1.87
+			Added -A, -s, -S flag, allowed SOLARIS to ignore 
+			file systems via MNTOPT_IGNORE/MNTTYPE_IGNORE, 
+			fixed slight resource problems, fixed man page. 
+	28-03-96: 1.88
+			Changed address to Robert_Gasch@peoplesoft.com, 
+			fixed some warnings gcc -Wall showed
 
   ************************************************************************* */
 
@@ -258,12 +288,14 @@ int 			show_use=TRUE,		/* do we show user or root */
 			fs_border=1,		/* file system border */
 			percent=TRUE,		/* show percent */
 			absolute=FALSE,		/* make bar size relative */
+			available=FALSE,	/* show available MB */
 			bell=FALSE,		/* ring bell for warning */
 			verbose=FALSE,		/* verbose mode */
 			sort=FALSE,		/* do we sort by name? */
 			gray,			/* use gray fill */
 			idx[MAXFS],		/* index to use when sorting */
 			show_blocks,		/* compatability in util.c */
+			show_biggest=FALSE,	/* show biggest size */
 #ifdef SCO
 			root=TRUE;		/* root or non-root */
 #else
@@ -301,6 +333,7 @@ static XrmOptionDescRec opTable[] = {
 {"+rv",		"*reverseVideo", XrmoptionNoArg,	(char *) "off"},
 {"+synchronous","*synchronous",	XrmoptionNoArg,		(char *) "off"},
 {"-?",		".help",	XrmoptionNoArg,		(char *) "on"},
+{"-A",		".available",	XrmoptionNoArg,		(char *) "on"},
 {"-a",		".absolute",	XrmoptionNoArg,		(char *) "on"},
 {"-background",	"*background",	XrmoptionSepArg,	(char *) NULL},
 {"-b",		".gray",	XrmoptionNoArg,		(char *) "off"},
@@ -329,6 +362,7 @@ static XrmOptionDescRec opTable[] = {
 #endif
 {"-rs",		".reserved_space",XrmoptionSepArg,	(char *) "NULL"},
 {"-rv",		"*reverseVideo", XrmoptionNoArg,	(char *) "on"},
+{"-sb",		".showbiggest" , XrmoptionNoArg,	(char *) "on"},
 {"-sort",	".sort",	XrmoptionNoArg,		(char *) "on"},
 {"-synchronous","*synchronous",	XrmoptionNoArg,		(char *) "on"},
 {"-v",		".verbose",	XrmoptionNoArg,		(char *) "on"},
