@@ -1,5 +1,5 @@
 /* ************************************************************************* *
-   xfsm - (C) Copyright 1993 Robert Gasch (rgasch@nl.oracle.com)
+   xfsm - (C) Copyright 1993-1996 Robert Gasch (Robert_Gasch@peoplesoft.com)
 
    Permission to use, copy, modify and distribute this software for any 
    purpose and without fee is hereby granted, provided that this copyright
@@ -11,7 +11,7 @@
    any purpose. This software is provided "as is" without express or implied 
    warranty.
 
-   All commercial uses of xfsm must be done by agreement with the autor.
+   See the GNU General Public Licence for more information.
  * ************************************************************************* */
 
 
@@ -41,9 +41,11 @@ extern int 			show_use,
 				detail_share_color,
 				minimize,
 				menu_border,
+				show_biggest,
 				fs_border,
 				percent,
 				absolute,
+				available,
 				bell,
 				verbose,
 				sort,
@@ -67,14 +69,18 @@ extern struct statfs 		stats[];
 
 
 static MyString ignore_names[MAXFS],	/* *** file systems to be ignored *** */
+		select_names[MAXFS],	/* *** file systems to be selected*** */
 #ifndef SCO
 		ignore_type[MAXFS],	/* *** FS types to ignore *** */
 		only_type,		/* *** show only this type *** */
 #endif /* !SCO */
-		ignore_pattern[MAXFS];	/* *** FSN patterns to be ignored *** */
+		ignore_pattern[MAXFS],	/* *** FSN patterns to be ignored *** */
+		select_pattern[MAXFS];	/* *** FSN patterns to be selected*** */
 static int	lname,
 		ignore_n_count=0,
 		ignore_p_count=0,
+		select_n_count=0,
+		select_p_count=0,
 #ifndef SCO
 		ignore_t_count=0,
 		only_t=FALSE,
@@ -316,7 +322,7 @@ int i;
 	XDrawImageString (mydisplay, detail_win.win, detail_win.gc, 
 		OFF_X+lhs, OFF_Y+MENU_HEIGHT(detail_win)*c++, s, strlen (s));
 
-#if defined (SVR4) || defined (SOLARIS) || defined (AUX)
+#if defined (SVR4) || defined (SOLARIS) || defined (AUX) || defined (SGI)
 	XDrawImageString (mydisplay, detail_win.win, detail_win.gc, 
 		OFF_X, OFF_Y+MENU_HEIGHT(detail_win)*c, "Inodes Available",
 		strlen ("Inodes Available"));
@@ -328,7 +334,7 @@ int i;
 	CHECKNA;
 	XDrawImageString (mydisplay, detail_win.win, detail_win.gc, 
 		OFF_X+lhs, OFF_Y+MENU_HEIGHT(detail_win)*c++, s, strlen (s));
-#endif
+#endif /* SVR4 || SOLARIS || AUX || SGI */
 }
 
 
@@ -339,11 +345,10 @@ int i;
 void get_fs ()
 {
 	int		x,y, removed, min, t, fs_returned=0;
-	MyString	ts;
 #if defined (SVR4) || defined (SOLARIS) || defined (SCO) || \
     defined (SUNOS) || defined (LINUX) || defined (HPUX) || \
     defined (CONVEXOS) || defined (MACH) || defined (DYNIX) || \
-    defined (AUX)
+    defined (AUX) || defined (SGI)
 	FILE		*fp;
 #endif
 #ifdef ULTRIX
@@ -360,7 +365,8 @@ void get_fs ()
 /* *** we still have porting exceptions here are that the functions *** */
 /* *** we call have different parameter types we have to adhere to. *** */
 #if defined (SUNOS) || defined (LINUX) || defined (DYNIX) || \
-    defined (HPUX) || defined (AIX) || defined (CONVEXOS) || defined (AUX)
+    defined (HPUX) || defined (AIX) || defined (CONVEXOS) || \
+    defined (AUX) || defined (SGI)
 	struct mntent 	*mnt_info;
 # else
 # if defined (SVR4) || defined (SOLARIS) || defined (ULTRIX) || defined (MACH) 
@@ -371,7 +377,7 @@ void get_fs ()
 	int		i, nstatfs;
 #  endif /* OSF1 || FreeBSD */
 # endif /* SVR4 || SOLARIS || ULTRIX || MACH */
-#endif /* SUNOS || LINUX || DYNIX || HPUX || AIX || CONVEXOS || AUX */
+#endif /* SUNOS || LINUX || DYNIX || HPUX || AIX || CONVEXOS || AUX || SGI */
 
 
 	NFS=0;
@@ -379,7 +385,8 @@ void get_fs ()
 	/* *** AIX && ULTRIX do not have to do this as we   *** */
 	/* *** acces the mount data directly though memory  *** */
 #if defined (SUNOS) || defined (LINUX) || defined (HPUX) || \
-    defined (CONVEXOS) || defined (MACH) || defined (DYNIX) || defined (AUX)
+    defined (CONVEXOS) || defined (MACH) || defined (DYNIX) || \
+    defined (AUX) || defined (SGI)
 	if ((fp=setmntent(MOUNT_FILE,"r"))==NULL)
 		{
 		perror("Can't open setmntent ... Exiting");
@@ -432,12 +439,13 @@ void get_fs ()
 #   endif /* FreeBSD */
 #  endif /* OSF1 */
 # endif /* SVR4 || SOLARIS */
-#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || DYNIX || AUX */
+#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || DYNIX || AUX || SGI */
 
 
 	/* *** read the contents of the file *** */
 #if defined (SUNOS) || defined (LINUX) || defined (HPUX) || \
-    defined (CONVEXOS) || defined (MACH) || defined(DYNIX) || defined (AUX)
+    defined (CONVEXOS) || defined (MACH) || defined(DYNIX) || \
+    defined (AUX) || defined (SGI)
 	while ((mnt_info=getmntent(fp)) && NFS < MAXFS)
 # else
 # if defined (SVR4) || defined (SOLARIS)
@@ -473,13 +481,14 @@ Please change the definition of BUFFERSIZE in main.h to an appropriate value\n",
 #   endif /* AIX */
 #  endif /* OSF1 || FreeBSD */
 # endif /* SVR4 || SOLARIS */
-#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || AUX */
+#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || AUX || SGI */
 
 
 		{
 		/* *** here the actual while loop starts *** */
 #if defined (SUNOS) || defined (LINUX) || defined (DYNIX) || \
-    defined (HPUX) || defined (CONVEXOS) || defined (MACH) || defined (AUX) 
+    defined (HPUX) || defined (CONVEXOS) || defined (MACH) || \
+    defined (AUX) || defined (SGI)
 		strcpy (strinfo[NFS].fs_name, mnt_info->mnt_dir);
 		strcpy (strinfo[NFS].dev_name, mnt_info->mnt_fsname);
 		strcpy (strinfo[NFS].mnt_typ, mnt_info->mnt_type);
@@ -585,28 +594,31 @@ Please change the definition of BUFFERSIZE in main.h to an appropriate value\n",
 #   endif /* AIX */
 #  endif /* OSF1 */
 # endif /* SVR4 || SOLARIS */
-#endif /* SUNOS || LINUX || DYNIX || HPUX || ULTRIX || CONVEXOS || MACH || AUX*/
+#endif /* SUNOS || LINUX || DYNIX || HPUX || ULTRIX || CONVEXOS || MACH || 
+          AUX || SGI */
 
 
 		/* *** see if this is one of the file *** */
 		/* *** systems that we want to remove *** */
 		removed=FALSE;
-#if !defined (SVR4) && !defined (SOLARIS) && !defined (MACH) && \
-    !defined (AIX) && !defined (OSF1) && !defined (SCO) && !defined (FreeBSD)
-		/* *** As far as I know this does not exist for SYSV *** */
-		/* *** If someone knowledgable knows that it does,   *** */
-		/* *** please let me know 			     *** */
+#if !defined (MACH) && !defined (AIX) && !defined (OSF1) && \
+    !defined (SCO) && !defined (FreeBSD)
 		/* *** AIX does not need it as we use mntctl         *** */
 		/* *** OSF1 neither as it uses getfsstat             *** */
-#if defined(ULTRIX)
+# ifdef ULTRIX
 		if (mnt_info.mnt_type == fs_ignore)
 			removed=TRUE;
-#else
+# else
+#  if defined (SOLARIS) || defined (SVR4)
+		if (strstr(mnt_info.mnt_opts, fs_ignore))
+			removed=TRUE;
+#   else  
+		/* *** generic comparison *** */
 		if (!strcmp(mnt_info->mnt_type, fs_ignore))
 			removed=TRUE;
-#endif /* ULTRIX */
-#endif /* !SVR4 && !SOLARIS && !MACH && !AIX && !OSF1 && !SCO && !FreeBSD */
-
+#  endif /* SOLARIS || SVR4 */
+# endif /* ULTRIX */
+#endif /* !MACH && !AIX && !OSF1 && !SCO && !FreeBSD */
 
 		/* *** see if the user has any options which affect *** */
 		/* *** which file systems we show *** */
@@ -643,6 +655,31 @@ Please change the definition of BUFFERSIZE in main.h to an appropriate value\n",
 #endif /* !SCO */
 
 		/* *** FS was not targeted by -d, -D, -it or -ot option *** */
+		if (!removed && (select_n_count > 0))
+			{
+			removed=TRUE;
+			for (x=0; x<select_n_count; x++)
+				/* *** we found a match *** */
+				if (!strcmp (strinfo[NFS].fs_name, 
+				    	     select_names[x]))
+					{
+					removed=FALSE;
+					x=select_n_count;
+					}
+			}
+		if (!removed && (select_p_count > 0))
+			{
+			removed=TRUE;
+			for (x=0; x<select_p_count; x++)
+				/* *** we found a match *** */
+				if (strstr (strinfo[NFS].fs_name,
+					    select_pattern[x])!=NULL)
+					{
+					removed=FALSE;
+					x=select_n_count;
+					}
+			}
+				
 		if (!removed)
 			NFS++;
 		fs_returned++;
@@ -655,7 +692,7 @@ Please change the definition of BUFFERSIZE in main.h to an appropriate value\n",
 	/* *** AIX and OSF1: Same as AIX        *** */
 	/* *** although we free the buffer      *** */
 #if defined (SUNOS) || defined (LINUX) || defined (HPUX) || \
-    defined (CONVEXOS) || defined (MACH) || defined (AUX)
+    defined (CONVEXOS) || defined (MACH) || defined (AUX) || defined (SGI)
 	endmntent(fp);
 # else
 # if defined (SVR4) || defined (SOLARIS) || defined (SCO)
@@ -669,7 +706,7 @@ Please change the definition of BUFFERSIZE in main.h to an appropriate value\n",
 #   endif /* OSF1 */
 #  endif /* AIX */
 # endif /* SVR4 || SOLARIS */
-#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || DYNIX || AUX */
+#endif /* SUNOS || LINUX || HPUX || CONVEXOS || MACH || DYNIX || AUX || SGI */
 
 	if (NFS==MAXFS)
 		{
@@ -718,13 +755,14 @@ Exiting\n");
 void get_fs_stat()
 {
 	static time_t	last_mod_time=0;
-	int 		i, t, x, old_lname=lname, updated=FALSE;
+	int 		i, t, x, old_lname=lname, updated=FALSE, shortcut=TRUE;
 	double		blocks,
 			bfree,
 #ifndef SCO
 			bavail,
 #endif
-			bsize;
+			bsize,
+			orig_blocks;
 	struct stat	stat_info;
 
 #if !defined (AIX) && !defined (ULTRIX) && !defined (OSF1) && !defined (FreeBSD)
@@ -757,8 +795,10 @@ void get_fs_stat()
 		}
 #else
 	/* *** get mounted file systems unconditionally *** */
+	/* *** we can't check with stat() to save time *** */
 	lname=0;
 	updated=TRUE;
+	shortcut=FALSE;
 	get_fs ();
 #endif /* !AIX && !ULTRIX && !OSF1 && !FreeBSD */
 
@@ -773,17 +813,17 @@ void get_fs_stat()
 		{
 #if defined (SUNOS) || defined (LINUX) || defined (AIX) || defined (HPUX) || \
     defined (ULTRIX) || defined (CONVEXOS) || defined (MACH) || \
-    defined (OSF1) || defined (FreeBSD) || defined (AUX)
+    defined (OSF1) || defined (FreeBSD) || defined (AUX) 
 #undef statfs
 		t=statfs (FsName, &stats[i]);
 # else
-# if defined (SVR4) || defined (SOLARIS)
+# if defined (SVR4) || defined (SOLARIS) || defined (SGI)
 		t=statvfs (FsName, &stats[i]);
 #  else
 #  if defined (DYNIX) || defined (SCO)
 		t=statfs (FsName, &stats[i], sizeof(struct statfs), 0);
 #  endif /* DYNIX || SCO */
-# endif /* SVR4 || SOLARIS */
+# endif /* SVR4 || SOLARIS || SGI */
 #endif /* SUNOS || LINUX || AIX || HPUX || ULTRIX || CONVEXOS || MACH || \
           OSF1 || FreeBSD || AUX */
 
@@ -834,7 +874,7 @@ void get_fs_stat()
 		/* *** throw out file systems of size 0 *** */
 		if (blocks == 0)
 			{
-			if (verbose && turns)
+			if (verbose && turns && shortcut)
 			 printf ("File system %s is of size 0 - ignoring it!\n",
 				FsName);
 			for (x=i; x<NFS; x++)
@@ -883,10 +923,17 @@ void get_fs_stat()
 			   /* *** account for the reserved     *** */
 			   /* *** space and decrease the       *** */
 			   /* *** number of blocks accordingly *** */
+			   orig_blocks=blocks;
 			   blocks *= (1-res_space);
 	   		   if (show_use)
 				{
-				fs_perc[i]=(float) ((blocks-bavail)/blocks);
+				/* *** msdos doesn't know reserved space *** */
+				if (strstr (strinfo[i].mnt_typ, "msdos"))
+					fs_perc[i]=(float)((orig_blocks-bavail)/
+						blocks);
+				else
+					fs_perc[i]=(float) 
+						((blocks-bavail)/blocks);
 # ifdef DEBUG
 	   			printf ("Free: %f \t Total: %f == %.2f%%\n", 
 					bfree, blocks, fs_perc[i]);
@@ -894,7 +941,11 @@ void get_fs_stat()
 				} 
 	   		  else
 				{
-	   			fs_perc[i]=(float) (bavail/blocks);
+				/* *** msdos doesn't know reserved space *** */
+				if (strstr (strinfo[i].mnt_typ, "msdos"))
+	   				fs_perc[i]=(float) (bavail/orig_blocks);
+				else
+	   				fs_perc[i]=(float) (bavail/blocks);
 # ifdef DEBUG
 	   			printf ("Free: %f \t Total: %f == %.2f%%\n", 
 					bfree, bavail, fs_perc[i]);
@@ -955,13 +1006,35 @@ char **argv;
 XrmDatabase commandlineDB;
 {
 	char name[MAXPATHLEN];
+	char msg[255];
 	int i;
 
-	/* *** Load in the app-defaults file. *** */
-	strcpy(name, APP_DEFAULTS_DIR);
-	strcat(name, "/");
-	strcat(name, CLASS_NAME);
-	resourceDB = XrmGetFileDatabase(name);
+	strcpy (msg, "");
+	/* *** Load the local app-defaults file. *** */
+	if (getenv ("XAPPLRESDIR"))
+		{
+		strcpy(name, getenv ("XAPPLRESDIR"));
+		strcat(name, "/");
+		strcat(name, CLASS_NAME);
+		resourceDB = XrmGetFileDatabase(name);
+		if (resourceDB)
+			sprintf (msg, 
+				"Read Resource definitions in %s ...", name);
+		}
+		
+
+	/* *** check if we really found something *** */
+	/* *** if not, check in APP_DEFAULTS_DIR *** */
+	if (!resourceDB) 
+		{
+		strcpy(name, APP_DEFAULTS_DIR);
+		strcat(name, "/");
+		strcat(name, CLASS_NAME);
+		resourceDB = XrmGetFileDatabase(name);
+		if (resourceDB)
+			sprintf(msg, "Read Resource definitions in %s ...",
+				name);
+		}
 
 	/* *** Load in any definitions supplied in the X server. *** */
 	if (XResourceManagerString(mydisplay) != NULL)
@@ -977,12 +1050,14 @@ XrmDatabase commandlineDB;
 			do_help();
 
 	/* *** See if the verbose flag was set. *** */
-	if (verbose = getBoolResource(resourceDB,
+	if ((verbose = getBoolResource(resourceDB,
 		catlist(myname, ".verbose", (char*) NULL), 
-		"Xfsm.Verbose", False)) 
+		"Xfsm.Verbose", False))) 
 		{
 		PRINT_COPYRIGHT;
 		puts ("-v flag caught - verbose mode enabled...");
+		if (resourceDB && strlen (msg))
+			puts (msg);
 		}
 
 	/* *** this one has to go befor the -fg evaluation   *** */
@@ -1009,20 +1084,20 @@ gray fill disabled.\n");
 		WhitePixel (mydisplay, DefaultScreen (mydisplay)));
 	if (bg != WhitePixel (mydisplay, DefaultScreen (mydisplay)))
 		if (verbose) 
-			printf ("-fg flag caught - background set\n");
+			printf ("-bg flag caught - background set\n");
 
 #ifndef SCO
-	if (root = getBoolResource(resourceDB, 
-		catlist(myname, ".root", (char*) NULL), "Xfsm.Root", False)) 
+	if ((root = getBoolResource(resourceDB, 
+		catlist(myname, ".root", (char*) NULL), "Xfsm.Root", False))) 
 		{
 		if (verbose)
 			puts("-r flag caught - will give statistics for root.");
 		}
 #endif
 
-	if (minimize = getIntResource(resourceDB,
+	if ((minimize = getIntResource(resourceDB,
 		catlist(myname, ".minimize", (char*) NULL), 
-		"Xfsm.Minimize", False))
+		"Xfsm.Minimize", False)))
 		if (verbose)
 			if (minimize == MNL)
 				puts("-mnl flag caught - will minimize \
@@ -1031,15 +1106,15 @@ window with regard to FS name length.");
 				puts("-m flag caught - will minimize \
 window size.");
 
-	if (menu_border = getBoolResource(resourceDB,
+	if ((menu_border = getBoolResource(resourceDB,
 		catlist(myname, ".menuborder", (char*)NULL),
-		"XFsm.Menuborder", False))
+		"Xfsm.Menuborder", False)))
 		if (verbose)
 			puts("-mb flag caught - will draw menu border.");
 
-	if (fs_border = getBoolResource(resourceDB,
+	if ((fs_border = getBoolResource(resourceDB,
 		catlist(myname, ".fs_border", (char*)NULL),
-		"XFsm.Fs_border", True));
+		"Xfsm.Fs_border", True)));
 	else
 		if (verbose)
 			puts("-fsb flag caught - will not draw file system \
@@ -1048,12 +1123,25 @@ border.");
 	if (!(percent = getBoolResource(resourceDB,
 		catlist(myname, ".percent", (char*) NULL),
 		"Xfsm.Percent", True)))
+		{
+		available=FALSE;
 		if (verbose) 
 			puts("-p flag caught - will turn percent display off.");
+		}
 
-	if (absolute = getBoolResource(resourceDB,
+	if ((available = getBoolResource(resourceDB,
+		catlist(myname, ".available", (char*) NULL),
+		"Xfsm.Available", False))) 
+			{
+			percent=FALSE;
+			if (verbose)
+				puts("-A flag caught - will show available \
+space in MBs");
+			}
+
+	if ((absolute = getBoolResource(resourceDB,
 		catlist(myname, ".absolute", (char*) NULL), 
-		"Xfsm.Absolute", False))
+		"Xfsm.Absolute", False)))
 		if (verbose)
 			puts("-a flag caught - will display sizes relative \
 to absolute FS size.");
@@ -1064,21 +1152,28 @@ to absolute FS size.");
 			puts("-f flag caught - will show space free rather \
 than space used.");
 
-	if (bell = getBoolResource(resourceDB,
-		catlist(myname, ".bell", (char*) NULL), "Xfsm.Bell", False))
+	if ((show_biggest = getBoolResource(resourceDB,
+		catlist(myname, ".showbiggest", (char*) NULL), 
+		"Xfsm.ShowBiggest", False)))
+		if (verbose)
+			puts("-sb flag caught - will show biggest file \
+system size.");
+
+	if ((bell = getBoolResource(resourceDB,
+		catlist(myname, ".bell", (char*) NULL), "Xfsm.Bell", False)))
 		if (verbose)
 			puts("-e flag caught - will extend warning to \
 include a beep.");
 
-	if (sort = getBoolResource(resourceDB,
+	if ((sort = getBoolResource(resourceDB,
 		catlist(myname, ".sort", (char*) NULL), 
-		"Xfsm.Sort", False)) 
+		"Xfsm.Sort", False))) 
 		if (verbose)
 			puts ("-sort flag caught - will sort by name ...");
 
-	if (detail_share_color = getBoolResource(resourceDB,
+	if ((detail_share_color = getBoolResource(resourceDB,
 		catlist(myname, ".detailWin.share", (char*) NULL),
-		"Xfsm.detailWin.Share", False))
+		"Xfsm.detailWin.Share", False)))
 		if (verbose)
 		puts ("Detail window will have the same color as the \
 file system it is displaying.");
@@ -1176,21 +1271,21 @@ level 3 to %f %%.\n", warn3val);
 		{
 		if (verbose)
 			printf ("-wl1c flag caught - warning level 1 color \
-set to %d ...\n", warn1col);
+set to %d ...\n", (int)warn1col);
 		}
 	if ((warn2col = getColorResource(resourceDB, catlist(myname, 
 		".warn2col",(char*)NULL),"Xfsm.Warn2col",warn1col))!=warn1col) 
 		{
 		if (verbose)
 			printf ("-wl2c flag caught - warning level 2 color \
-set to %d ...\n", warn2col);
+set to %d ...\n", (int)warn2col);
 		}
 	if ((warn3col = getColorResource(resourceDB, catlist(myname, 
 		".warn3col",(char*)NULL),"Xfsm.Warn3col",warn2col))!=warn2col) 
 		{
 		if (verbose)
 			printf ("-wl3c flag caught - warning level 3 color \
-set to %d ...\n", warn3col);
+set to %d ...\n", (int)warn3col);
 		}
 
 	if ((upd_interval = getIntResource(resourceDB,
@@ -1268,6 +1363,44 @@ matching %s ...\n", argv[i + 1]);
 ... %s ignored\n", argv[i + 1]);
 			i++;
 			} 
+	else
+	if (!strcmp (argv[i], "-s"))
+		/* *** does it begin with an "-" *** */
+		while (i < (argc - 1) && argv[i + 1][0] != '-')
+			{
+			if (select_n_count < MAXFS)
+				{
+				if (verbose)
+				    printf ("Will select %s ...\n", argv[i+1]);
+				strcpy (select_names[select_n_count++],
+					argv[i + 1]);
+				}
+			else
+				fprintf (stderr,
+					"Exceeded number of selected file \
+systems ... %s ignored.\n", argv[i+1]);
+			i++;
+			}
+	else
+	if (!strcmp (argv[i], "-S"))
+		/* *** does it begin with an "-" *** */
+		while (i < (argc - 1) && argv[i + 1][0] != '-')
+			{
+			/* *** check all file systems for arg *** */
+			if (select_p_count < MAXFS)
+				{
+				if (verbose)
+					printf ("Will select patterns \
+matching %s ...\n", argv[i + 1]);
+				strcpy (select_pattern[select_p_count++],
+					argv[i + 1]);
+				}
+			else
+				fprintf (stderr,
+					"Exceeded number of select patterns \
+... %s ignored\n", argv[i + 1]);
+			i++;
+			}
 #ifndef SCO
 	else
 	if (!strcmp (argv[i], "-it"))
@@ -1326,6 +1459,7 @@ printf ("\n\
         +rv                     reverse video (use to override xrdb entry)\n\
         +synchronous            syncronous mode (use to override xrdb entry)\n\
         -?                      help\n\
+	-A			show available space in MBs\n\
         -a                      absolute display mode\n\
         -background <arg>       backgound color \n\
         -b                      black bars (disable gray fill)\n\
@@ -1368,8 +1502,12 @@ printf ("\
 #endif /* !SCO */
 printf ("\
 	-rs <arg>		specify the amount of space reserved for root\n\
-					default = %d%%\n\
+					default = %d%% \n\
         -rv                     reverse video\n\
+	-s <arg1 ... argn>	select only these file systems\n\
+	-S <arg1 ... argn>	select only file systems matching these patterns\n\
+	-sb			show biggest file system size in lower right\n\
+	-sort			sort file systems according to name\n\
         -synchronous            synchronous mode\n\
         -v                      verbose\n\
         -w <arg>                display warning pix when usage reaches <arg>%\n\
